BatchItem

Struct BatchItem 

pub struct BatchItem<E, J>
where E: Pairing, J: TECurveConfig<BaseField = E::ScalarField>,
{ /* private fields */ }
A ring proof preprocessed for multi-ring batch verification.

Implementations

Source

impl<E, J> BatchItem<E, J>
where E: Pairing, J: TECurveConfig<BaseField = E::ScalarField>,

pub fn new<T>( verifier: &RingVerifier<E::ScalarField, KZG<E>, J, T>, proof: RingProof<E::ScalarField, KZG<E>>, result: Affine<J>, ) -> Self
where T: PlonkTranscript<E::ScalarField, KZG<E>>,

Prepares a ring proof for batch verification without accumulating it.

The returned item is independent of both any accumulator state and the originating RingVerifier, so multiple proofs (even from different rings) can be prepared in parallel.