pub struct WrappedAffine<C>(pub <C as CurveGroup>::Affine)
where
C: CurveGroup;Expand description
KZG commitment to G1 represented in affine coordinates.
Tuple Fields
0: <C as CurveGroup>::AffineTrait Implementations
Sourceimpl<C> Add for WrappedAffine<C>where
C: CurveGroup,
impl<C> Add for WrappedAffine<C>where
C: CurveGroup,
Sourcetype Output = WrappedAffine<C>
type Output = WrappedAffine<C>
The resulting type after applying the
+ operator.Sourcefn add(self, other: WrappedAffine<C>) -> WrappedAffine<C>
fn add(self, other: WrappedAffine<C>) -> WrappedAffine<C>
Performs the
+ operation. Read moreSourceimpl<C> CanonicalDeserialize for WrappedAffine<C>where
C: CurveGroup,
impl<C> CanonicalDeserialize for WrappedAffine<C>where
C: CurveGroup,
Sourcefn deserialize_with_mode<R>(
reader: R,
compress: Compress,
validate: Validate,
) -> Result<WrappedAffine<C>, SerializationError>where
R: Read,
fn deserialize_with_mode<R>(
reader: R,
compress: Compress,
validate: Validate,
) -> Result<WrappedAffine<C>, SerializationError>where
R: Read,
The general deserialize method that takes in customization flags.
Sourcefn deserialize_compressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_compressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
Reads
Self from reader using the compressed form if applicable.
Performs validation if applicable.Sourcefn deserialize_compressed_unchecked<R>(
reader: R,
) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_compressed_unchecked<R>(
reader: R,
) -> Result<Self, SerializationError>where
R: Read,
Reads
Self from reader using the compressed form if applicable, without validating the
deserialized value. Read moreSourcefn deserialize_uncompressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_uncompressed<R>(reader: R) -> Result<Self, SerializationError>where
R: Read,
Reads
Self from reader using the uncompressed form. Performs validation if applicable.Sourcefn deserialize_uncompressed_unchecked<R>(
reader: R,
) -> Result<Self, SerializationError>where
R: Read,
fn deserialize_uncompressed_unchecked<R>(
reader: R,
) -> Result<Self, SerializationError>where
R: Read,
Reads
Self from reader using the uncompressed form, without validating the deserialized
value. Read moreSourceimpl<C> CanonicalSerialize for WrappedAffine<C>where
C: CurveGroup,
impl<C> CanonicalSerialize for WrappedAffine<C>where
C: CurveGroup,
Sourcefn serialize_with_mode<W>(
&self,
writer: W,
compress: Compress,
) -> Result<(), SerializationError>where
W: Write,
fn serialize_with_mode<W>(
&self,
writer: W,
compress: Compress,
) -> Result<(), SerializationError>where
W: Write,
The general serialize method that takes in customization flags.
Sourcefn serialized_size(&self, compress: Compress) -> usize
fn serialized_size(&self, compress: Compress) -> usize
Returns the size in bytes of the serialized version of
self with the given compression mode.Sourcefn serialize_compressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
fn serialize_compressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
Serializes
self into writer using the compressed form if applicable.Sourcefn compressed_size(&self) -> usize
fn compressed_size(&self) -> usize
Returns the size in bytes of the compressed serialized version of
self.Sourcefn serialize_uncompressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
fn serialize_uncompressed<W>(&self, writer: W) -> Result<(), SerializationError>where
W: Write,
Serializes
self into writer using the uncompressed form.Sourcefn uncompressed_size(&self) -> usize
fn uncompressed_size(&self) -> usize
Returns the size in bytes of the uncompressed serialized version of
self.Sourceimpl<C> Clone for WrappedAffine<C>
impl<C> Clone for WrappedAffine<C>
Sourcefn clone(&self) -> WrappedAffine<C>
fn clone(&self) -> WrappedAffine<C>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C> Commitment<<C as PrimeGroup>::ScalarField> for WrappedAffine<C>where
C: CurveGroup,
impl<C> Commitment<<C as PrimeGroup>::ScalarField> for WrappedAffine<C>where
C: CurveGroup,
fn mul(&self, by: <C as PrimeGroup>::ScalarField) -> WrappedAffine<C>
fn combine( coeffs: &[<C as PrimeGroup>::ScalarField], commitments: &[WrappedAffine<C>], ) -> WrappedAffine<C>
Sourceimpl<C> Debug for WrappedAffine<C>
impl<C> Debug for WrappedAffine<C>
impl<C> Eq for WrappedAffine<C>
Sourceimpl<C> Mul<<C as PrimeGroup>::ScalarField> for WrappedAffine<C>where
C: CurveGroup,
impl<C> Mul<<C as PrimeGroup>::ScalarField> for WrappedAffine<C>where
C: CurveGroup,
Sourcetype Output = WrappedAffine<C>
type Output = WrappedAffine<C>
The resulting type after applying the
* operator.Sourcefn mul(self, by: <C as PrimeGroup>::ScalarField) -> WrappedAffine<C>
fn mul(self, by: <C as PrimeGroup>::ScalarField) -> WrappedAffine<C>
Performs the
* operation. Read moreSourceimpl<C> PartialEq for WrappedAffine<C>
impl<C> PartialEq for WrappedAffine<C>
impl<C> StructuralPartialEq for WrappedAffine<C>
Sourceimpl<C> Sub for WrappedAffine<C>where
C: CurveGroup,
impl<C> Sub for WrappedAffine<C>where
C: CurveGroup,
Sourcetype Output = WrappedAffine<C>
type Output = WrappedAffine<C>
The resulting type after applying the
- operator.Sourcefn sub(self, other: WrappedAffine<C>) -> WrappedAffine<C>
fn sub(self, other: WrappedAffine<C>) -> WrappedAffine<C>
Performs the
- operation. Read moreSourceimpl<C> Sum for WrappedAffine<C>where
C: CurveGroup,
impl<C> Sum for WrappedAffine<C>where
C: CurveGroup,
Sourcefn sum<I>(iter: I) -> WrappedAffine<C>where
I: Iterator<Item = WrappedAffine<C>>,
fn sum<I>(iter: I) -> WrappedAffine<C>where
I: Iterator<Item = WrappedAffine<C>>,
Takes an iterator and generates
Self from the elements by “summing up”
the items.Sourceimpl<C> Valid for WrappedAffine<C>where
C: CurveGroup,
impl<C> Valid for WrappedAffine<C>where
C: CurveGroup,
Sourceconst TRIVIAL_CHECK: bool = <C::Affine as ark_serialize::Valid>::TRIVIAL_CHECK
const TRIVIAL_CHECK: bool = <C::Affine as ark_serialize::Valid>::TRIVIAL_CHECK
Whether the
check method is trivial (i.e. always returns Ok(())). If this is true,
the batch_check method will skip all checks and return Ok(()).
This should be set to true for types where check is trivial, e.g.
integers, field elements, etc.
This is false by default.
This is primarily an optimization to skip unnecessary checks in batch_check.Sourcefn check(&self) -> Result<(), SerializationError>
fn check(&self) -> Result<(), SerializationError>
Checks whether
self is valid. If self is valid, returns Ok(()). Otherwise, returns
an error describing the failure.
This method is called by deserialize_with_mode if validate is Validate::Yes.Sourcefn batch_check<'a>(
batch: impl Iterator<Item = &'a WrappedAffine<C>> + Send,
) -> Result<(), SerializationError>where
WrappedAffine<C>: 'a,
fn batch_check<'a>(
batch: impl Iterator<Item = &'a WrappedAffine<C>> + Send,
) -> Result<(), SerializationError>where
WrappedAffine<C>: 'a,
Checks whether all items in
batch are valid. If all items are valid, returns Ok(()).
Otherwise, returns an error describing the first failure.Auto Trait Implementations
impl<C> Freeze for WrappedAffine<C>
impl<C> RefUnwindSafe for WrappedAffine<C>
impl<C> Send for WrappedAffine<C>
impl<C> Sync for WrappedAffine<C>
impl<C> Unpin for WrappedAffine<C>
impl<C> UnsafeUnpin for WrappedAffine<C>
impl<C> UnwindSafe for WrappedAffine<C>