pub struct Ring<F: PrimeField, KzgCurve: Pairing<ScalarField = F>, G: AffineRepr<BaseField = F>> {
pub cx: KzgCurve::G1Affine,
pub cy: KzgCurve::G1Affine,
pub selector: KzgCurve::G1Affine,
pub max_keys: usize,
pub curr_keys: usize,
pub padding: G,
}Expand description
Commitment to a list of VRF public keys as is used as a public input to the ring proof SNARK verifier.
The VRF keys are (inner) curve points that we represent in the affine Twisted Edwards coordinates.
We commit to the coordinate vectors independently using KZG on the outer curve. To make the commitment
updatable we use SRS in the Lagrangian form: L1, ..., Ln, where Li = L_i(t)G.
The commitment to a vector a1, ..., an is then a1L1 + ... + anLn.
We pad the list of keys with a padding point with unknown dlog up to a certain size.
Additionally, to make the commitment compatible with the snark,
we append the power-of-2 powers of the VRF blinding Pedersen base
H, 2H, 4H, ..., 2^(s-1)H, where s is the bitness of the VRF curve scalar field.
The last IDLE_ROWS = 4 elements are set to (0, 0).
Thus, the vector of points we commit to coordinatewise is
pk1, ..., pkn, padding, ..., padding, H, 2H, ..., 2^(s-1)H, 0, 0, 0, 0
Fields
cx: KzgCurve::G1AffineKZG commitment to the x coordinates of the described vector.
cy: KzgCurve::G1AffineKZG commitment to the y coordinates of the described vector.
selector: KzgCurve::G1AffineKZG commitment to a bitvector highlighting the part of the vector corresponding to the public keys.
max_keys: usizeMaximal number of keys the commitment can “store”. For domain of size N it is N - (s + IDLE_ROWS).
curr_keys: usizeNumber of keys “stored” in this commitment.
padding: GImplementations
Sourceimpl<F: PrimeField, KzgCurve: Pairing<ScalarField = F>, G: AffineRepr<BaseField = F>> Ring<F, KzgCurve, G>
impl<F: PrimeField, KzgCurve: Pairing<ScalarField = F>, G: AffineRepr<BaseField = F>> Ring<F, KzgCurve, G>
Sourcepub fn empty(
piop_params: &PiopParams<G>,
srs: impl Fn(Range<usize>) -> Result<Vec<KzgCurve::G1Affine>, ()>,
g: KzgCurve::G1,
) -> Self
pub fn empty( piop_params: &PiopParams<G>, srs: impl Fn(Range<usize>) -> Result<Vec<KzgCurve::G1Affine>, ()>, g: KzgCurve::G1, ) -> Self
Builds the commitment to the vector
padding, ..., padding, H, 2H, ..., 2^(s-1)H, 0, 0, 0, 0.
We compute it as a sum of commitments of 2 vectors:
padding, ..., padding, and
0, ..., 0, (H - padding), (2H - padding), ..., (2^(s-1)H - padding), -padding, -padding, -padding, -padding.
The first one is padding * G, the second requires an (IDLE_ROWS + s)-msm to compute.
piop_params: SNARK parameterssrs: Should returnsrs[range]forrange = (piop_params.keyset_part_size..domain_size)g: Generator used in the SRS
Sourcepub fn append(
&mut self,
keys: &[G],
srs: impl Fn(Range<usize>) -> Result<Vec<KzgCurve::G1Affine>, ()>,
)
pub fn append( &mut self, keys: &[G], srs: impl Fn(Range<usize>) -> Result<Vec<KzgCurve::G1Affine>, ()>, )
Appends a set key sequence to the ring.
keys: Keys to append.srs: Should returnsrs[range]forrange = (self.curr_keys..self.curr_keys + keys.len())
Sourcepub fn with_keys(
piop_params: &PiopParams<G>,
keys: &[G],
srs: &RingBuilderKey<F, KzgCurve>,
) -> Self
pub fn with_keys( piop_params: &PiopParams<G>, keys: &[G], srs: &RingBuilderKey<F, KzgCurve>, ) -> Self
Builds the ring from the keys provided with 2 MSMs of size keys.len() + scalar_bitlen + 5.
In some cases it may be beneficial to cash the empty ring, as updating it costs 2 MSMs of size keys.len().
piop_params: SNARK parameters.srs: full-size Lagrangian SRS.
pub fn slots_left(&self) -> usize
pub const fn empty_unchecked( domain_size: usize, cx: KzgCurve::G1Affine, cy: KzgCurve::G1Affine, selector: KzgCurve::G1Affine, padding: G, ) -> Self