pub struct BatchItem<E, J>{ /* private fields */ }Expand description
A ring proof preprocessed for multi-ring batch verification.
Implementations
Sourceimpl<E, J> BatchItem<E, J>
impl<E, J> BatchItem<E, J>
Sourcepub fn new<T>(
verifier: &RingVerifier<E::ScalarField, KZG<E>, J, T>,
proof: RingProof<E::ScalarField, KZG<E>>,
result: Affine<J>,
) -> Self
pub fn new<T>( verifier: &RingVerifier<E::ScalarField, KZG<E>, J, T>, proof: RingProof<E::ScalarField, KZG<E>>, result: Affine<J>, ) -> Self
Prepares a ring proof for batch verification without accumulating it.
The returned item is independent of both any accumulator state and
the originating RingVerifier, so multiple proofs (even from
different rings) can be prepared in parallel.